@@ -139,7 +139,7 @@ class FormBase(ViewBase):
             <span id=":error"></span>
         </td></tr>
     </table>
-    		<input type="submit" value="Save" id="submit"/>
+    		<input type="submit" value="Save"/>
     </form>
 
     Forms created with sprox can be validated as you would any other widget.
@@ -305,6 +305,7 @@ class FormBase(ViewBase):
         args = {}
         args['not_empty'] = (not self.__provider__.is_nullable(self.__entity__, field_name)) or \
                              field_name in self.__require_fields__
+        args['required'] = args['not_empty']
 
         widget_type = self._do_get_field_wiget_type(field_name, field)
         if widget_type and (issubclass(widget_type, CalendarDatePicker) or
@@ -388,14 +389,14 @@ class AddRecordForm(FormBase):
     <form enctype="multipart/form-data" method="post">
          <span class="error"></span>
         <table >
-        <tr class="odd required"  id="sx_user_name:container">
+        <tr class="odd"  id="sx_user_name:container">
             <th>User Name</th>
             <td >
                 <input name="user_name" type="text" id="sx_user_name" value=""/>
                 <span id="sx_user_name:error"></span>
             </td>
         </tr>
-        <tr class="even required"  id="sx_email_address:container">
+        <tr class="even"  id="sx_email_address:container">
             <th>Email Address</th>
             <td >
                 <input name="email_address" type="text" id="sx_email_address"/>
@@ -409,7 +410,7 @@ class AddRecordForm(FormBase):
                 <span id="sx_display_name:error"></span>
             </td>
         </tr>
-        <tr class="even required"  id="sx_password:container">
+        <tr class="even"  id="sx_password:container">
             <th>Password</th>
             <td >
                 <input type="password" name="password" id="sx_password"/>
@@ -428,7 +429,7 @@ class AddRecordForm(FormBase):
             <span id=":error"></span>
         </td></tr>
     </table>
-        <input type="submit" value="Save" id="submit"/>
+        <input type="submit" value="Save"/>
     </form>
 
 
@@ -455,8 +456,8 @@ class AddRecordForm(FormBase):
     def _do_init_attrs(self):
         super(AddRecordForm, self)._do_init_attrs()
 
-        if not self.__omit_fields__:
-            pkey = self.__provider__.get_primary_field(self.__entity__)
+        pkey = self.__provider__.get_primary_field(self.__entity__)
+        if pkey not in self.__omit_fields__:
             self.__omit_fields__.append(pkey)
 
     def _do_get_disabled_fields(self):
@@ -506,7 +507,7 @@ class DisabledForm(FormBase):
             <span id=":error"></span>
         </td></tr>
     </table>
-        <input type="submit" value="Save" id="submit"/>
+        <input type="submit" value="Save"/>
     </form>
 
 
