@@ -3,8 +3,8 @@ from nose.tools import raises, eq_
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 
-from sprox.metadata import Metadata, MetadataError, FieldsMetadata, FieldMetadata, EntitiesMetadata
-from sprox.saormprovider import SAORMProvider
+from sprox.metadata import Metadata, MetadataError, FieldsMetadata, FieldMetadata, EntitiesMetadata, NotFoundError
+from sprox.sa.provider import SAORMProvider
 from sprox.iprovider import IProvider
 from sprox.test.base import *
 
