@@ -1,13 +1,12 @@
 from nose.tools import raises, eq_
-from tw.forms.fields import *
-from tw.api import Widget
 from sqlalchemy import Column, Integer
 from sqlalchemy.types import *
 from sqlalchemy.orm import class_mapper
 
-from sprox.widgetselector import WidgetSelector, SAWidgetSelector, EntityDefWidget, EntityDefWidgetSelector, RecordFieldWidget, RecordViewWidgetSelector
-from sprox.widgets.widgets import *
-from sprox.saormprovider import SAORMProvider
+from sprox.widgetselector import WidgetSelector, EntityDefWidget, EntityDefWidgetSelector, RecordFieldWidget, RecordViewWidgetSelector
+from sprox.sa.widgetselector import SAWidgetSelector
+from sprox.widgets import *
+from sprox.sa.provider import SAORMProvider
 from sprox.test.model import Document
 
 class TestWidgetSelector:
